﻿///////////////////////////////////////////////////////////////////////////////////////////////////
// 
//  ACT距離計算サービス サンプルプログラム
//  CalcSettingsクラス
//
//  Copyrights (c) 2016-2023, Advanced Core Technologies, Inc. All rights reserved.
//
//  2023/09/21 Rev.1.0.0.1 KYON UseSsl変数をプロパティに変更
//  2016/01/28 Rev.1.0.0.0 MOTO 作成
//
///////////////////////////////////////////////////////////////////////////////////////////////////

using Act.Dcws;

namespace ACTSOAPCSSearchAddress
{
    /// <summary>
    /// 距離計算サービスに使用する設定を指定します。
    /// </summary>
    internal static class CalcSettings
    {
        //=========================================================================================
        //  Public Constants
        //=========================================================================================
        #region Public Constants

        /// <summary>
        /// 管理サービスURLの既定値です。
        /// </summary>
        public static readonly string DefaultAdminUrl = 
            @"https://distcalc.act-inc.co.jp/dcadmin/admin.asmx";

        /// <summary>
        /// 経緯度の測地系を指定します。日本測地系。
        /// </summary>
        public static readonly Datum Datum = Datum.Tokyo;

        /// <summary>
        /// 経緯度の座標フォーマット識別子を指定します。現在は常に0を指定します。
        /// </summary>
        public static readonly int CoordinateFormat = 0;

        /// <summary>
        /// 住所検索用フラグを指定します。なし。
        /// </summary>
        public static readonly SearchAddressFlag SearchFlag = SearchAddressFlag.None;

        #endregion

        //=========================================================================================
        //  Public Property
        //=========================================================================================
        #region Public Property

        /// <summary>
        /// 通信プロトコルにSSLを使用するかどうかを指定します。
        /// true：SSLを使用する、false：SSLを使用しない
        /// </summary>
        public static bool UseSsl { get; set; } = false;

        #endregion
    }
}
